Skip to content

[AUTOGENERATED] [release/2.10] [ROCm] Fixed memory errors in SymmetricMemory caused by repeated call…#3405

Draft
rocm-repo-management-api-6[bot] wants to merge 1 commit into
release/2.10from
autogenerated/release/2.10_cherry-pick_pr-3403
Draft

[AUTOGENERATED] [release/2.10] [ROCm] Fixed memory errors in SymmetricMemory caused by repeated call…#3405
rocm-repo-management-api-6[bot] wants to merge 1 commit into
release/2.10from
autogenerated/release/2.10_cherry-pick_pr-3403

Cherry-picked commit with merge conflict

899e864
Select commit
Loading
Failed to load commit list.
ROCm Repo Management API / Jenkins failed Jul 7, 2026 in 1h 12m 31s

Initialize/Build PyTorch: error in 'error' step

Initialize / Build PyTorch / Shell Script

Error in sh step, with arguments #!/usr/bin/bash set -o pipefail ./build_pytorch.sh 2>&1 | tee build_pytorch.log .

script returned exit code 1
Build log
Build log truncated.

[2026-07-07T21:35:00.693Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.693Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h: In instantiation of ���auto at::cuda::tunable::GetRocBlasGemmTypeStringAndOps() [with T = c10::complex<float>]���:
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:217:65:   required from ���at::cuda::tunable::GemmTunableOp<T, ALayout, BLayout>::GemmTunableOp() [with T = c10::complex<float>; at::cuda::tunable::BlasOp ALayout = at::cuda::tunable::BlasOp::T; at::cuda::tunable::BlasOp BLayout = at::cuda::tunable::BlasOp::T]���
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1461:82:   required from ���void at::cuda::blas::gemm_tunable(char, char, int64_t, int64_t, int64_t, at::opmath_type<Dtype>, const DType*, int64_t, const DType*, int64_t, at::opmath_type<Dtype>, C_Dtype*, int64_t) [with DType = c10::complex<float>; C_Dtype = c10::complex<float>; int64_t = long int; at::opmath_type<Dtype> = c10::complex<float>]���
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1518:38:   required from here
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.693Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.693Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.693Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.693Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.693Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.693Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.693Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.693Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.693Z]       |                            ^~~~
[2026-07-07T21:35:00.693Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.693Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.693Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h: In instantiation of ���auto at::cuda::tunable::GetRocBlasGemmTypeStringAndOps() [with T = c10::Half]���:
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:217:65:   required from ���at::cuda::tunable::GemmTunableOp<T, ALayout, BLayout>::GemmTunableOp() [with T = c10::Half; at::cuda::tunable::BlasOp ALayout = at::cuda::tunable::BlasOp::T; at::cuda::tunable::BlasOp BLayout = at::cuda::tunable::BlasOp::T]���
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1461:82:   required from ���void at::cuda::blas::gemm_tunable(char, char, int64_t, int64_t, int64_t, at::opmath_type<Dtype>, const DType*, int64_t, const DType*, int64_t, at::opmath_type<Dtype>, C_Dtype*, int64_t) [with DType = c10::Half; C_Dtype = c10::Half; int64_t = long int; at::opmath_type<Dtype> = float]���
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1529:27:   required from here
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.694Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.694Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h: In instantiation of ���auto at::cuda::tunable::GetRocBlasGemmTypeStringAndOps() [with T = c10::BFloat16]���:
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:217:65:   required from ���at::cuda::tunable::GemmTunableOp<T, ALayout, BLayout>::GemmTunableOp() [with T = c10::BFloat16; at::cuda::tunable::BlasOp ALayout = at::cuda::tunable::BlasOp::T; at::cuda::tunable::BlasOp BLayout = at::cuda::tunable::BlasOp::T]���
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1461:82:   required from ���void at::cuda::blas::gemm_tunable(char, char, int64_t, int64_t, int64_t, at::opmath_type<Dtype>, const DType*, int64_t, const DType*, int64_t, at::opmath_type<Dtype>, C_Dtype*, int64_t) [with DType = c10::BFloat16; C_Dtype = c10::BFloat16; int64_t = long int; at::opmath_type<Dtype> = float]���
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPBlas.cpp:1540:31:   required from here
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.694Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:182:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.694Z]   182 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.694Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.694Z]   183 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   184 |                                                             input_output_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   185 |                                                             compute_type,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   186 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z]   187 |                                                             nullptr,
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~
[2026-07-07T21:35:00.694Z]   188 |                                                             &solution_size));
[2026-07-07T21:35:00.694Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.694Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.694Z]       |                            ^~~~
[2026-07-07T21:35:00.694Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.694Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.694Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.694Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.695Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.695Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.695Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.695Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.695Z]       |                            ^~~~
[2026-07-07T21:35:00.695Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.695Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.695Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:191:60: warning: ���rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle, rocblas_datatype, rocblas_datatype, rocblas_datatype, uint32_t, rocblas_int*, rocblas_int*)��� is deprecated: "rocblas_gemm_ex_get_solutions_by_type is a beta feature and is subject to " "change in future releases" [-Wdeprecated-declarations]
[2026-07-07T21:35:00.695Z]   191 |   TORCH_ROCBLAS_CHECK(rocblas_gemm_ex_get_solutions_by_type(handle,
[2026-07-07T21:35:00.695Z]       |                       ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~^~~~~~~~
[2026-07-07T21:35:00.695Z]   192 |                                                             input_output_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   193 |                                                             input_output_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   194 |                                                             compute_type,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   195 |                                                             rocblas_gemm_flags_none,
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   196 |                                                             solutions.data(),
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z]   197 |                                                             &solution_size));
[2026-07-07T21:35:00.695Z]       |                                                             ~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:18:28: note: in definition of macro ���TORCH_ROCBLAS_CHECK���
[2026-07-07T21:35:00.695Z]    18 |     rocblas_status __err = EXPR;                  \
[2026-07-07T21:35:00.695Z]       |                            ^~~~
[2026-07-07T21:35:00.695Z] /opt/rocm-7.2.4/include/rocblas/internal/rocblas-beta.h:217:31: note: declared here
[2026-07-07T21:35:00.695Z]   217 | ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex_get_solutions_by_type(rocblas_handle   handle,
[2026-07-07T21:35:00.695Z]       |                               ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h: At global scope:
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:46:13: warning: ���bool at::cuda::tunable::_transposeBoolFromChar(char)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:00.695Z]    46 | static bool _transposeBoolFromChar(char op) {
[2026-07-07T21:35:00.695Z]       |             ^~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:00.695Z] In file included from /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:15:
[2026-07-07T21:35:00.695Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmHipblaslt.h:404:13: warning: ���char at::cuda::tunable::_charFromhipblasOp(hipblasOperation_t)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:00.695Z]   404 | static char _charFromhipblasOp(hipblasOperation_t op) {
[2026-07-07T21:35:00.695Z]       |             ^~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:01.049Z] [7667/8132] Building CXX object caffe2/CMakeFiles/static_runtime_test.dir/__/benchmarks/static_runtime/deep_wide_pt.cc.o
[2026-07-07T21:35:01.049Z] [7668/8132] Building CXX object caffe2/CMakeFiles/static_runtime_bench.dir/__/benchmarks/static_runtime/deep_wide_pt_bench.cc.o
[2026-07-07T21:35:01.802Z] [7669/8132] Building CXX object caffe2/CMakeFiles/torch_hip.dir/__/torch/csrc/jit/tensorexpr/cuda_codegen.cpp.o
[2026-07-07T21:35:01.802Z] cc1plus: warning: command-line option ���-Wno-duplicate-decl-specifier��� is valid for C/ObjC but not for C++
[2026-07-07T21:35:01.802Z] In file included from /var/lib/jenkins/pytorch/c10/macros/Export.h:1,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/c10/util/Exception.h:4,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/BlasBackend.h:3,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/Context.h:3,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/ATen.h:7,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/torch/csrc/jit/tensorexpr/cuda_codegen.h:5,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/torch/csrc/jit/tensorexpr/cuda_codegen.cpp:2:
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:134: warning: "TORCH_HIP_CPP_API" redefined
[2026-07-07T21:35:01.802Z]   134 | #define TORCH_HIP_CPP_API C10_EXPORT
[2026-07-07T21:35:01.802Z]       | 
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:129: note: this is the location of the previous definition
[2026-07-07T21:35:01.802Z]   129 | #define TORCH_HIP_CPP_API C10_IMPORT
[2026-07-07T21:35:01.802Z]       | 
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:135: warning: "TORCH_HIP_API" redefined
[2026-07-07T21:35:01.802Z]   135 | #define TORCH_HIP_API C10_EXPORT
[2026-07-07T21:35:01.802Z]       | 
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:130: note: this is the location of the previous definition
[2026-07-07T21:35:01.802Z]   130 | #define TORCH_HIP_API C10_IMPORT
[2026-07-07T21:35:01.802Z]       | 
[2026-07-07T21:35:01.802Z] In file included from /var/lib/jenkins/pytorch/torch/csrc/jit/tensorexpr/cuda_codegen.h:7:
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:130:5: warning: ���hipError_t hipCtxGetCurrent(ihipCtx_t**)��� is deprecated: This API is marked as deprecated and might not be supported in future releases. For more details please refer https://github.com/ROCm/HIP/blob/develop/docs/reference/deprecated_api_list.md [-Wdeprecated-declarations]
[2026-07-07T21:35:01.802Z]   130 |   _(hipCtxGetCurrent)                              \
[2026-07-07T21:35:01.802Z]       |     ^~~~~~~~~~~~~~~~
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:138:39: note: in definition of macro ���CREATE_MEMBER���
[2026-07-07T21:35:01.802Z]   138 | #define CREATE_MEMBER(name) decltype(&name) name;
[2026-07-07T21:35:01.802Z]       |                                       ^~~~
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:139:3: note: in expansion of macro ���AT_FORALL_NVRTC���
[2026-07-07T21:35:01.802Z]   139 |   AT_FORALL_NVRTC(CREATE_MEMBER)
[2026-07-07T21:35:01.802Z]       |   ^~~~~~~~~~~~~~~
[2026-07-07T21:35:01.802Z] In file included from /opt/rocm-7.2.4/include/hip/hip_runtime.h:65,
[2026-07-07T21:35:01.802Z]                  from /var/lib/jenkins/pytorch/torch/csrc/jit/tensorexpr/cuda_codegen.cpp:1:
[2026-07-07T21:35:01.802Z] /opt/rocm-7.2.4/include/hip/hip_runtime_api.h:6024:12: note: declared here
[2026-07-07T21:35:01.802Z]  6024 | hipError_t hipCtxGetCurrent(hipCtx_t* ctx);
[2026-07-07T21:35:01.802Z]       |            ^~~~~~~~~~~~~~~~
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:133:5: warning: ���hipError_t hipDevicePrimaryCtxGetState(hipDevice_t, unsigned int*, int*)��� is deprecated: This API is marked as deprecated and might not be supported in future releases. For more details please refer https://github.com/ROCm/HIP/blob/develop/docs/reference/deprecated_api_list.md [-Wdeprecated-declarations]
[2026-07-07T21:35:01.802Z]   133 |   _(hipDevicePrimaryCtxGetState)
[2026-07-07T21:35:01.802Z]       |     ^~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:138:39: note: in definition of macro ���CREATE_MEMBER���
[2026-07-07T21:35:01.802Z]   138 | #define CREATE_MEMBER(name) decltype(&name) name;
[2026-07-07T21:35:01.802Z]       |                                       ^~~~
[2026-07-07T21:35:01.802Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/nvrtc_stub/ATenNVRTC.h:139:3: note: in expansion of macro ���AT_FORALL_NVRTC���
[2026-07-07T21:35:01.802Z]   139 |   AT_FORALL_NVRTC(CREATE_MEMBER)
[2026-07-07T21:35:01.802Z]       |   ^~~~~~~~~~~~~~~
[2026-07-07T21:35:01.802Z] /opt/rocm-7.2.4/include/hip/hip_runtime_api.h:6227:12: note: declared here
[2026-07-07T21:35:01.802Z]  6227 | hipError_t hipDevicePrimaryCtxGetState(hipDevice_t dev, unsigned int* flags, int* active);
[2026-07-07T21:35:01.802Z]       |            ^~~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:03.043Z] [7670/8132] Building CXX object caffe2/CMakeFiles/static_runtime_bench.dir/__/benchmarks/static_runtime/deep_wide_pt.cc.o
[2026-07-07T21:35:04.897Z] [7671/8132] Building CXX object caffe2/CMakeFiles/torch_hip.dir/__/torch/csrc/distributed/c10d/FlightRecorderCuda.cpp.o
[2026-07-07T21:35:04.897Z] cc1plus: warning: command-line option ���-Wno-duplicate-decl-specifier��� is valid for C/ObjC but not for C++
[2026-07-07T21:35:04.897Z] In file included from /var/lib/jenkins/pytorch/c10/macros/Export.h:1,
[2026-07-07T21:35:04.897Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/hip/ATenHIPGeneral.h:8,
[2026-07-07T21:35:04.897Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPEvent.h:4,
[2026-07-07T21:35:04.897Z]                  from /var/lib/jenkins/pytorch/torch/csrc/distributed/c10d/FlightRecorderCuda.cpp:2:
[2026-07-07T21:35:04.897Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:134: warning: "TORCH_HIP_CPP_API" redefined
[2026-07-07T21:35:04.897Z]   134 | #define TORCH_HIP_CPP_API C10_EXPORT
[2026-07-07T21:35:04.897Z]       | 
[2026-07-07T21:35:04.897Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:129: note: this is the location of the previous definition
[2026-07-07T21:35:04.897Z]   129 | #define TORCH_HIP_CPP_API C10_IMPORT
[2026-07-07T21:35:04.897Z]       | 
[2026-07-07T21:35:04.897Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:135: warning: "TORCH_HIP_API" redefined
[2026-07-07T21:35:04.897Z]   135 | #define TORCH_HIP_API C10_EXPORT
[2026-07-07T21:35:04.897Z]       | 
[2026-07-07T21:35:04.897Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:130: note: this is the location of the previous definition
[2026-07-07T21:35:04.897Z]   130 | #define TORCH_HIP_API C10_IMPORT
[2026-07-07T21:35:04.897Z]       | 
[2026-07-07T21:35:06.818Z] [7672/8132] Building CXX object caffe2/CMakeFiles/static_runtime_test.dir/__/benchmarks/static_runtime/test_static_module.cc.o
[2026-07-07T21:35:13.797Z] [7673/8132] Building CXX object caffe2/CMakeFiles/static_runtime_test.dir/__/benchmarks/static_runtime/test_generated_ops.cc.o
[2026-07-07T21:35:14.592Z] [7674/8132] Building CXX object caffe2/CMakeFiles/static_runtime_test.dir/__/benchmarks/static_runtime/test_static_runtime.cc.o
[2026-07-07T21:35:18.788Z] [7675/8132] Building CXX object caffe2/CMakeFiles/torch_hip.dir/__/torch/csrc/distributed/c10d/ProcessGroupNCCL.cpp.o
[2026-07-07T21:35:18.788Z] cc1plus: warning: command-line option ���-Wno-duplicate-decl-specifier��� is valid for C/ObjC but not for C++
[2026-07-07T21:35:18.788Z] In file included from /var/lib/jenkins/pytorch/c10/macros/Export.h:1,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/c10/core/DeviceType.h:3,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/c10/core/Device.h:3,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/c10/core/Allocator.h:10,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPContextLight.h:29,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPContext.h:4,
[2026-07-07T21:35:18.788Z]                  from /var/lib/jenkins/pytorch/torch/csrc/distributed/c10d/ProcessGroupNCCL.cpp:12:
[2026-07-07T21:35:18.788Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:134: warning: "TORCH_HIP_CPP_API" redefined
[2026-07-07T21:35:18.788Z]   134 | #define TORCH_HIP_CPP_API C10_EXPORT
[2026-07-07T21:35:18.788Z]       | 
[2026-07-07T21:35:18.788Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:129: note: this is the location of the previous definition
[2026-07-07T21:35:18.788Z]   129 | #define TORCH_HIP_CPP_API C10_IMPORT
[2026-07-07T21:35:18.788Z]       | 
[2026-07-07T21:35:18.788Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:135: warning: "TORCH_HIP_API" redefined
[2026-07-07T21:35:18.788Z]   135 | #define TORCH_HIP_API C10_EXPORT
[2026-07-07T21:35:18.788Z]       | 
[2026-07-07T21:35:18.788Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:130: note: this is the location of the previous definition
[2026-07-07T21:35:18.788Z]   130 | #define TORCH_HIP_API C10_IMPORT
[2026-07-07T21:35:18.788Z]       | 
[2026-07-07T21:35:18.788Z] /var/lib/jenkins/pytorch/torch/csrc/distributed/c10d/ProcessGroupNCCL.cpp:206:13: warning: ���std::string c10d::{anonymous}::getNcclAbortedCommStoreKey(const std::string&)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:18.788Z]   206 | std::string getNcclAbortedCommStoreKey(const std::string& ncclIdStr) {
[2026-07-07T21:35:18.788Z]       |             ^~~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:42.485Z] [7676/8132] Building CXX object caffe2/CMakeFiles/torch_hip.dir/__/aten/src/ATen/native/hip/ScaledBlas.cpp.o
[2026-07-07T21:35:42.485Z] cc1plus: warning: command-line option ���-Wno-duplicate-decl-specifier��� is valid for C/ObjC but not for C++
[2026-07-07T21:35:42.485Z] In file included from /var/lib/jenkins/pytorch/c10/macros/Export.h:1,
[2026-07-07T21:35:42.485Z]                  from /var/lib/jenkins/pytorch/c10/util/typeid.h:14,
[2026-07-07T21:35:42.485Z]                  from /var/lib/jenkins/pytorch/aten/src/ATen/native/hip/ScaledBlas.cpp:3:
[2026-07-07T21:35:42.485Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:134: warning: "TORCH_HIP_CPP_API" redefined
[2026-07-07T21:35:42.485Z]   134 | #define TORCH_HIP_CPP_API C10_EXPORT
[2026-07-07T21:35:42.485Z]       | 
[2026-07-07T21:35:42.485Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:129: note: this is the location of the previous definition
[2026-07-07T21:35:42.485Z]   129 | #define TORCH_HIP_CPP_API C10_IMPORT
[2026-07-07T21:35:42.485Z]       | 
[2026-07-07T21:35:42.485Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:135: warning: "TORCH_HIP_API" redefined
[2026-07-07T21:35:42.485Z]   135 | #define TORCH_HIP_API C10_EXPORT
[2026-07-07T21:35:42.485Z]       | 
[2026-07-07T21:35:42.485Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:130: note: this is the location of the previous definition
[2026-07-07T21:35:42.485Z]   130 | #define TORCH_HIP_API C10_IMPORT
[2026-07-07T21:35:42.485Z]       | 
[2026-07-07T21:35:42.485Z] In file included from /var/lib/jenkins/pytorch/aten/src/ATen/native/hip/ScaledBlas.cpp:17:
[2026-07-07T21:35:42.485Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPScaledBlas.h:87:13: warning: ���bool at::cuda::scaled::_scaled_mm_is_fnuz()��� defined but not used [-Wunused-function]
[2026-07-07T21:35:42.486Z]    87 | static bool _scaled_mm_is_fnuz() {
[2026-07-07T21:35:42.486Z]       |             ^~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:42.486Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPScaledBlas.h:63:13: warning: ���bool at::cuda::scaled::_scaled_mm_allowed_device(bool, bool)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:42.486Z]    63 | static bool _scaled_mm_allowed_device(bool sm90_only=false, bool sm100_only=false) {
[2026-07-07T21:35:42.486Z]       |             ^~~~~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:42.486Z] In file included from /var/lib/jenkins/pytorch/aten/src/ATen/hip/HIPScaledBlas.h:18:
[2026-07-07T21:35:42.486Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:46:13: warning: ���bool at::cuda::tunable::_transposeBoolFromChar(char)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:42.486Z]    46 | static bool _transposeBoolFromChar(char op) {
[2026-07-07T21:35:42.486Z]       |             ^~~~~~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:42.486Z] In file included from /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:16:
[2026-07-07T21:35:42.486Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmRocblas.h:122:26: warning: ���rocblas_operation at::cuda::tunable::_rocblasOpFromChar(char)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:42.486Z]   122 | static rocblas_operation _rocblasOpFromChar(char op) {
[2026-07-07T21:35:42.486Z]       |                          ^~~~~~~~~~~~~~~~~~
[2026-07-07T21:35:42.486Z] In file included from /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/TunableGemm.h:15:
[2026-07-07T21:35:42.486Z] /var/lib/jenkins/pytorch/aten/src/ATen/hip/tunable/GemmHipblaslt.h:404:13: warning: ���char at::cuda::tunable::_charFromhipblasOp(hipblasOperation_t)��� defined but not used [-Wunused-function]
[2026-07-07T21:35:42.486Z]   404 | static char _charFromhipblasOp(hipblasOperation_t op) {
[2026-07-07T21:35:42.486Z]       |             ^~~~~~~~~~~~~~~~~~
[2026-07-07T21:36:40.784Z] [7677/8132] Building CXX object caffe2/CMakeFiles/torch_hip.dir/__/aten/src/ATen/RegisterCUDA_0.cpp.o
[2026-07-07T21:36:40.784Z] cc1plus: warning: command-line option ���-Wno-duplicate-decl-specifier��� is valid for C/ObjC but not for C++
[2026-07-07T21:36:40.784Z] In file included from /var/lib/jenkins/pytorch/c10/macros/Export.h:1,
[2026-07-07T21:36:40.784Z]                  from /var/lib/jenkins/pytorch/c10/core/DeviceType.h:3,
[2026-07-07T21:36:40.784Z]                  from /var/lib/jenkins/pytorch/c10/core/Device.h:3,
[2026-07-07T21:36:40.784Z]                  from /var/lib/jenkins/pytorch/c10/core/Allocator.h:10,
[2026-07-07T21:36:40.784Z]                  from /var/lib/jenkins/pytorch/c10/core/TensorImpl.h:3,
[2026-07-07T21:36:40.784Z]                  from /var/lib/jenkins/pytorch/build/aten/src/ATen/RegisterCUDA_0.cpp:18:
[2026-07-07T21:36:40.784Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:134: warning: "TORCH_HIP_CPP_API" redefined
[2026-07-07T21:36:40.784Z]   134 | #define TORCH_HIP_CPP_API C10_EXPORT
[2026-07-07T21:36:40.784Z]       | 
[2026-07-07T21:36:40.784Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:129: note: this is the location of the previous definition
[2026-07-07T21:36:40.784Z]   129 | #define TORCH_HIP_CPP_API C10_IMPORT
[2026-07-07T21:36:40.784Z]       | 
[2026-07-07T21:36:40.784Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:135: warning: "TORCH_HIP_API" redefined
[2026-07-07T21:36:40.784Z]   135 | #define TORCH_HIP_API C10_EXPORT
[2026-07-07T21:36:40.784Z]       | 
[2026-07-07T21:36:40.784Z] /var/lib/jenkins/pytorch/torch/headeronly/macros/Export.h:130: note: this is the location of the previous definition
[2026-07-07T21:36:40.784Z]   130 | #define TORCH_HIP_API C10_IMPORT
[2026-07-07T21:36:40.784Z]       | 
[2026-07-07T21:36:40.784Z] ninja: build stopped: subcommand failed.
[2026-07-07T21:36:40.784Z] -- Checkout nccl release tag: v2.27.5-1
[2026-07-07T21:36:40.784Z] 
[2026-07-07T21:36:40.784Z] ERROR Backend subprocess exited when trying to invoke build_wheel
[2026-07-07T21:36:40.784Z] + sccache_epilogue
[2026-07-07T21:36:40.784Z] + echo '::group::Sccache Compilation Log'
[2026-07-07T21:36:40.784Z] + echo '=================== sccache compilation log ==================='
[2026-07-07T21:36:40.784Z] + python /var/lib/jenkins/pytorch/.ci/pytorch/print_sccache_log.py /root/sccache_error.log
[2026-07-07T21:36:40.784Z] ::group::Sccache Compilation Log
[2026-07-07T21:36:40.784Z] =================== sccache compilation log ===================
[2026-07-07T21:36:40.784Z] =========== If your build fails, please take a look at the log above for possible reasons ===========
[2026-07-07T21:36:40.784Z] + echo '=========== If your build fails, please take a look at the log above for possible reasons ==========='
[2026-07-07T21:36:40.784Z] + sccache --show-stats
[2026-07-07T21:36:40.784Z] Compile requests                   14189
[2026-07-07T21:36:40.784Z] Compile requests executed          11804
[2026-07-07T21:36:40.784Z] Cache hits                            12
[2026-07-07T21:36:40.784Z] Cache hits (C/C++)                    12
[2026-07-07T21:36:40.784Z] Cache misses                       11759
[2026-07-07T21:36:40.784Z] Cache misses (C/C++)               11401
[2026-07-07T21:36:40.784Z] Cache misses (HIP)                   358
[2026-07-07T21:36:40.784Z] Cache hits rate                     0.10 %
[2026-07-07T21:36:40.784Z] Cache hits rate (C/C++)             0.11 %
[2026-07-07T21:36:40.784Z] Cache hits rate (HIP)               0.00 %
[2026-07-07T21:36:40.784Z] Cache timeouts                         0
[2026-07-07T21:36:40.784Z] Cache read errors                      0
[2026-07-07T21:36:40.784Z] Forced recaches                        0
[2026-07-07T21:36:40.784Z] Cache write errors                     0
[2026-07-07T21:36:40.784Z] Cache errors                          25
[2026-07-07T21:36:40.784Z] Cache errors (C/C++)                  25
[2026-07-07T21:36:40.784Z] Compilations                       11759
[2026-07-07T21:36:40.784Z] Compilation failures                   8
[2026-07-07T21:36:40.784Z] Non-cacheable compilations             0
[2026-07-07T21:36:40.784Z] Non-cacheable calls                  376
[2026-07-07T21:36:40.784Z] Non-compilation calls               2009
[2026-07-07T21:36:40.784Z] Unsupported compiler calls             0
[2026-07-07T21:36:40.784Z] Average cache write                0.032 s
[2026-07-07T21:36:40.784Z] Average compiler                  12.440 s
[2026-07-07T21:36:40.784Z] Average cache read hit             0.037 s
[2026-07-07T21:36:40.785Z] Failed distributed compilations        0
[2026-07-07T21:36:40.785Z] 
[2026-07-07T21:36:40.785Z] Non-cacheable reasons:
[2026-07-07T21:36:40.785Z] -M                                   358
[2026-07-07T21:36:40.785Z] multiple input files                  13
[2026-07-07T21:36:40.785Z] unknown source language                2
[2026-07-07T21:36:40.785Z] -E                                     2
[2026-07-07T21:36:40.785Z] @                                      1
[2026-07-07T21:36:40.785Z] 
[2026-07-07T21:36:40.785Z] Cache location                  Local disk: "/root/.cache/sccache"
[2026-07-07T21:36:40.785Z] Use direct/preprocessor mode?   no
[2026-07-07T21:36:40.785Z] Version (client)                0.10.0
[2026-07-07T21:36:40.785Z] Cache size                           271 MiB
[2026-07-07T21:36:40.785Z] Max cache size                        10 GiB
[2026-07-07T21:36:40.785Z] + sccache --stop-server
[2026-07-07T21:36:40.785Z] Stopping sccache server...
[2026-07-07T21:36:40.785Z] Compile requests                   14189
[2026-07-07T21:36:40.785Z] Compile requests executed          11804
[2026-07-07T21:36:40.785Z] Cache hits                            12
[2026-07-07T21:36:40.785Z] Cache hits (C/C++)                    12
[2026-07-07T21:36:40.785Z] Cache misses                       11759
[2026-07-07T21:36:40.785Z] Cache misses (C/C++)               11401
[2026-07-07T21:36:40.785Z] Cache misses (HIP)                   358
[2026-07-07T21:36:40.785Z] Cache hits rate                     0.10 %
[2026-07-07T21:36:40.785Z] Cache hits rate (C/C++)             0.11 %
[2026-07-07T21:36:40.785Z] Cache hits rate (HIP)               0.00 %
[2026-07-07T21:36:40.785Z] Cache timeouts                         0
[2026-07-07T21:36:40.785Z] Cache read errors                      0
[2026-07-07T21:36:40.785Z] Forced recaches                        0
[2026-07-07T21:36:40.785Z] Cache write errors                     0
[2026-07-07T21:36:40.785Z] Cache errors                          25
[2026-07-07T21:36:40.785Z] Cache errors (C/C++)                  25
[2026-07-07T21:36:40.785Z] Compilations                       11759
[2026-07-07T21:36:40.785Z] Compilation failures                   8
[2026-07-07T21:36:40.785Z] Non-cacheable compilations             0
[2026-07-07T21:36:40.785Z] Non-cacheable calls                  376
[2026-07-07T21:36:40.785Z] Non-compilation calls               2009
[2026-07-07T21:36:40.785Z] Unsupported compiler calls             0
[2026-07-07T21:36:40.785Z] Average cache write                0.032 s
[2026-07-07T21:36:40.785Z] Average compiler                  12.440 s
[2026-07-07T21:36:40.785Z] Average cache read hit             0.037 s
[2026-07-07T21:36:40.785Z] Failed distributed compilations        0
[2026-07-07T21:36:40.785Z] 
[2026-07-07T21:36:40.785Z] Non-cacheable reasons:
[2026-07-07T21:36:40.785Z] -M                                   358
[2026-07-07T21:36:40.785Z] multiple input files                  13
[2026-07-07T21:36:40.785Z] -E                                     2
[2026-07-07T21:36:40.785Z] unknown source language                2
[2026-07-07T21:36:40.785Z] @                                      1
[2026-07-07T21:36:40.785Z] 
[2026-07-07T21:36:40.785Z] Cache location                  Local disk: "/root/.cache/sccache"
[2026-07-07T21:36:40.785Z] Use direct/preprocessor mode?   no
[2026-07-07T21:36:40.785Z] Version (client)                0.10.0
[2026-07-07T21:36:40.785Z] Cache size                           271 MiB
[2026-07-07T21:36:40.785Z] Max cache size                        10 GiB
[2026-07-07T21:36:40.785Z] ::endgroup::
[2026-07-07T21:36:40.785Z] + echo ::endgroup::

Output truncated.

Details

  • Kill older PR Builds (1.9 sec)
  • Initialize (1 hr 11 min)
    • Download CI scripts (51 sec)
    • Checkout Pytorch (3 min 43 sec)
    • Check base Docker image existence (10 sec)
    • Pull Docker Image (5 min 0 sec)
    • Build PyTorch (1 hr 0 min)
      Error: script returned exit code 1 - logs
      Error: *Found build error
      Regex: .FAILED:.
      Error: FAILED: caffe2/CMakeFiles/torch_hip.dir/__/torch/csrc/distributed/c10d/symm_mem/CUDASymmetricMemoryUtils.cpp.o * - logs
      Error: PyTorch build failed hudson.AbortException: script returned exit code 1 - logs
  • Tests (35 sec)
    • Test PyTorch (11 ms)
      • Test PyTorch (14 sec)
    • Test Distributed (10 ms)
      • Test Distributed (15 sec)
    • Test Inductor (16 ms)
      • Test Inductor (15 sec)
    • Test PyTorch Slow (15 ms)
      • Test PyTorch Slow (15 sec)
    • Microbenchmark (31 sec)
      • Microbenchmark (15 sec)
  • Post Build (3.5 sec)
  • Declarative: Post Actions (6.6 sec)